<?php

namespace Drupal\ad\Bucket;

use Drupal\ad\AdInterface;
use Drupal\ad\Size\SizeInterface;
use Drupal\ad\Track\TrackerInterface;

/**
 * Common interface for ad buckets.
 */
interface BucketInterface {

  /**
   * Builds an ad placeholder of the specified size.
   *
   * @param \Drupal\ad\Size\SizeInterface $size
   *   An ad size.
   *
   * @return array
   *   A renderable ad placeholder array.
   */
  public function buildPlaceholder(SizeInterface $size): array;

  /**
   * Builds an ad of the specified size.
   *
   * @param \Drupal\ad\Size\SizeInterface $size
   *   An ad size.
   *
   * @return array
   *   An ad render array.
   */
  public function buildAd(SizeInterface $size): array;

  /**
   * Returns the specified ad.
   *
   * @param string $id
   *   The ad identifier.
   *
   * @return \Drupal\ad\AdInterface|null
   *   An ad instance or NULL if none could be found.
   */
  public function getAd(string $id): ?AdInterface;

  /**
   * Returns the bucket's ad tracker.
   *
   * @return \Drupal\ad\Track\TrackerInterface
   *   A tracker instance.
   */
  public function getTracker(): TrackerInterface;

}
